Installation
============

.. note::
   AutoFolio was written in Python3.5. Probably, it will also run well with a Python 3 Version > 3.5. It is not compatible with Python 2.x

.. _manual_installation:

Manual Installation
-------------------
| To install AutoFolio from command line, please type the following commands on the command line

.. code-block:: bash

    cat requirements.txt | xargs -n 1 -L 1 pip install
    python setup.py install

 